pub struct ConnectOptions {
pub headers: Option<HashMap<String, String>>,
pub slow_mo: Option<f64>,
pub timeout: Option<f64>,
}Expand description
Options for BrowserType::connect.
Fields
headers: Option<HashMap<String, String>>Additional HTTP headers to send with the WebSocket handshake.
slow_mo: Option<f64>Slows down Playwright operations by the specified amount of milliseconds. Useful so that you can see what is going on.
timeout: Option<f64>Maximum time in milliseconds to wait for the connection to be established. Defaults to 30000 (30 seconds). Pass 0 to disable timeout.
Implementations