pub struct ConnectOverCdpOptions {
pub headers: Option<HashMap<String, String>>,
pub slow_mo: Option<f64>,
pub timeout: Option<f64>,
}Expand description
Options for BrowserType::connect_over_cdp.
Only supported for Chromium. Allows connecting to a Chrome DevTools Protocol endpoint,
such as those provided by browserless, Chrome with --remote-debugging-port, or other
CDP-compatible services.
See: https://playwright.dev/docs/api/class-browsertype#browser-type-connect-over-cdp
Fields
headers: Option<HashMap<String, String>>Additional HTTP headers to be sent with the connection request.
slow_mo: Option<f64>Slows down Playwright operations by the specified amount of milliseconds.
timeout: Option<f64>Maximum time in milliseconds to wait for the connection to be established. Defaults to 30000 (30 seconds). Pass 0 to disable timeout.
Implementations