Accessibility

Struct Accessibility 

pub struct Accessibility { /* private fields */ }
Provides accessibility-tree inspection methods on a page.

Access via Page::accessibility.

See: https://playwright.dev/docs/api/class-accessibility

Implementations

Source

impl Accessibility

pub async fn snapshot( &self, options: Option<AccessibilitySnapshotOptions>, ) -> Result<Value>

Captures the current state of the page’s accessibility tree.

Returns the accessibility tree as a JSON Value (tree of nodes with role, name, value, children, etc.), or null when there is no accessibility tree.

Errors

Returns error if the RPC call fails or the browser has been closed.

See: https://playwright.dev/docs/api/class-accessibility#accessibility-snapshot