APIRequest

Struct APIRequest 

pub struct APIRequest { /* private fields */ }
Factory for creating standalone APIRequestContext instances.

Obtained via playwright.request(). Use new_context() to create a context for making HTTP requests outside of a browser page.

APIRequest intentionally holds only the channel and connection reference, NOT a Playwright clone. Holding a Playwright clone would trigger the server shutdown Drop impl when the temporary APIRequest is dropped.

Example

use playwright_rs::protocol::Playwright;

#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
    let playwright = Playwright::launch().await?;

    let ctx = playwright.request().new_context(None).await?;
    let response = ctx.get("https://example.com/api/data", None).await?;
    assert!(response.ok());
    let body = response.text().await?;

    ctx.dispose().await?;
    playwright.shutdown().await?;
    Ok(())
}

See: https://playwright.dev/docs/api/class-apirequest

Implementations

Source

impl APIRequest

pub async fn new_context( &self, options: Option<APIRequestContextOptions>, ) -> Result<APIRequestContext>

Creates a new APIRequestContext for making HTTP requests.

Arguments
  • options — Optional configuration for the new context

See: https://playwright.dev/docs/api/class-apirequest#api-request-new-context