Module browser_context

Module browser_context 

Structs

BrowserContext
BrowserContextOptions
Allows customizing viewport, user agent, locale, timezone, geolocation, permissions, and other browser context settings.
BrowserContextOptionsBuilder
Builder for BrowserContextOptions
ClearCookiesOptions
Options for filtering which cookies to clear with BrowserContext::clear_cookies().
Cookie
Cookie information for storage state.
Geolocation
Geolocation coordinates.
GrantPermissionsOptions
Options for BrowserContext::grant_permissions().
LocalStorageItem
Local storage item for storage state.
Origin
Origin with local storage items for storage state.
RecordHar
Options for recording HAR.
RecordVideo
Options for recording video.
StorageState
Storage state containing cookies and local storage.
Viewport
Viewport dimensions for browser context.

Enums

AcceptDownloads
Options for creating a new browser context.