pub struct RecordHar {
pub path: String,
pub omit_content: Option<bool>,
pub content: Option<String>,
pub mode: Option<String>,
pub url_filter: Option<String>,
}Expand description
Options for recording HAR.
See: https://playwright.dev/docs/api/class-browser#browser-new-context-option-record-har
Fields
path: StringPath on the filesystem to write the HAR file to.
omit_content: Option<bool>Optional setting to control whether to omit request content from the HAR.
content: Option<String>Optional setting to control resource content management. “omit” | “embed” | “attach”
mode: Option<String>“full” | “minimal”
url_filter: Option<String>A glob or regex pattern to filter requests that are stored in the HAR.