pub struct ClockInstallOptions {
pub time: Option<u64>,
}Expand description
Options for Clock::install.
See: https://playwright.dev/docs/api/class-clock#clock-install
Fields
time: Option<u64>Initial time for the fake clock in milliseconds since the Unix epoch.
When None, the clock starts at the current real time.