#[non_exhaustive]pub struct ConsoleMessageLocation {
pub url: String,
pub line_number: i32,
pub column_number: i32,
}Expand description
The source location of a console message.
Contains the URL, line number, and column number of the JavaScript code that produced the console message.
See: https://playwright.dev/docs/api/class-consolemessage#console-message-location
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringThe URL of the resource that produced the console message.
line_number: i32The line number in the resource (1-based).
column_number: i32The column number in the resource (0-based).