pub enum WaitUntil {
Load,
DomContentLoaded,
NetworkIdle,
Commit,
}Expand description
When to consider navigation succeeded
Variants
Load
Consider operation to be finished when the load event is fired
DomContentLoaded
Consider operation to be finished when the DOMContentLoaded event is fired
NetworkIdle
Consider operation to be finished when there are no network connections for at least 500ms
Commit
Consider operation to be finished when the commit event is fired