pub struct AddScriptTagOptions {
pub content: Option<String>,
pub url: Option<String>,
pub path: Option<String>,
pub type_: Option<String>,
}Expand description
Options for adding a <script> tag to the page.
At least one of content, url, or path must be specified.
See: https://playwright.dev/docs/api/class-page#page-add-script-tag
Fields
content: Option<String>Raw JavaScript content to inject
url: Option<String>URL of the <script> tag to add
path: Option<String>Path to a JavaScript file to inject (file contents will be read and sent as content)
type_: Option<String>Script type attribute (e.g., "module")
Implementations
Sourceimpl AddScriptTagOptions
impl AddScriptTagOptions
Sourcepub fn builder() -> AddScriptTagOptionsBuilder
pub fn builder() -> AddScriptTagOptionsBuilder
Creates a new builder for AddScriptTagOptions