EmulateMediaOptions

Struct EmulateMediaOptions 

pub struct EmulateMediaOptions {
    pub media: Option<Media>,
    pub color_scheme: Option<ColorScheme>,
    pub reduced_motion: Option<ReducedMotion>,
    pub forced_colors: Option<ForcedColors>,
}
Options for page.emulate_media().

All fields are optional. Fields that are None are omitted from the protocol message (meaning they are not changed). To reset a field to browser default, use the NoOverride variant.

See: https://playwright.dev/docs/api/class-page#page-emulate-media

Fields

media: Option<Media>

Media type to emulate (screen, print, or no-override)

color_scheme: Option<ColorScheme>

Color scheme preference to emulate

reduced_motion: Option<ReducedMotion>

Reduced motion preference to emulate

forced_colors: Option<ForcedColors>

Forced colors preference to emulate

Implementations

Source

impl EmulateMediaOptions

pub fn builder() -> EmulateMediaOptionsBuilder

Creates a new builder for EmulateMediaOptions