Module proxy

Module proxy 

Network proxy settings

This module defines the ProxySettings struct which encapsulates the configuration for proxies used for network requests.

Proxy settings can be applied at both the browser launch level (LaunchOptions) and the browser context level (BrowserContextOptions).

See: https://playwright.dev/docs/api/class-browser#browser-new-context

Structs

ProxySettings
Network proxy settings for browser contexts and browser launches.