pub struct ResourceTiming {
pub start_time: f64,
pub domain_lookup_start: f64,
pub domain_lookup_end: f64,
pub connect_start: f64,
pub secure_connection_start: f64,
pub connect_end: f64,
pub request_start: f64,
pub response_start: f64,
pub response_end: f64,
}Expand description
Resource timing information for an HTTP request.
All time values are in milliseconds relative to the navigation start.
A value of -1 indicates the timing phase was not reached.
See: https://playwright.dev/docs/api/class-request#request-timing
Fields
start_time: f64Request start time in milliseconds since epoch.
domain_lookup_start: f64Time immediately before the browser starts the domain name lookup
for the resource. The value is given in milliseconds relative to
startTime, -1 if not available.
domain_lookup_end: f64Time immediately after the browser starts the domain name lookup
for the resource. The value is given in milliseconds relative to
startTime, -1 if not available.
connect_start: f64Time immediately before the user agent starts establishing the connection to the server to retrieve the resource.
secure_connection_start: f64Time immediately after the browser starts the handshake process to secure the current connection.
connect_end: f64Time immediately after the browser finishes establishing the connection to the server to retrieve the resource.
request_start: f64Time immediately before the browser starts requesting the resource from the server, cache, or local resource.
response_start: f64Time immediately after the browser starts requesting the resource from the server, cache, or local resource.
response_end: f64Time immediately after the browser receives the last byte of the resource or immediately before the transport connection is closed, whichever comes first.