TracingStartOptions

Struct TracingStartOptions 

#[non_exhaustive]
pub struct TracingStartOptions { pub name: Option<String>, pub screenshots: Option<bool>, pub snapshots: Option<bool>, pub live: Option<bool>, }
Options for starting a trace recording.

See: https://playwright.dev/docs/api/class-tracing#tracing-start

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>

Custom name for the trace. Shown in trace viewer as the trace title.

screenshots: Option<bool>

Whether to capture screenshots during tracing. Screenshots are used as a timeline preview in the trace viewer.

snapshots: Option<bool>

Whether to capture DOM snapshots on each action.

live: Option<bool>

Whether to enable live trace updates while recording. When true, the trace viewer can attach and observe the trace as it is being captured, rather than waiting for the recording to finish. Useful for debugging long-running flows.

See: https://playwright.dev/docs/api/class-tracing#tracing-start-option-live

Implementations

Source

impl TracingStartOptions

pub fn name(self, name: impl Into<String>) -> Self

Trace name (affects file naming in the traces directory).

pub fn screenshots(self, screenshots: bool) -> Self

Capture screenshots during tracing.

pub fn snapshots(self, snapshots: bool) -> Self

Capture DOM snapshots during tracing.

pub fn live(self, live: bool) -> Self

Enable live tracing (view in the trace viewer while running).