BrowserContextOptions

Struct BrowserContextOptions 

pub struct BrowserContextOptions {
Show 18 fields pub viewport: Option<Viewport>, pub no_viewport: Option<bool>, pub user_agent: Option<String>, pub locale: Option<String>, pub timezone_id: Option<String>, pub geolocation: Option<Geolocation>, pub permissions: Option<Vec<String>>, pub color_scheme: Option<String>, pub has_touch: Option<bool>, pub is_mobile: Option<bool>, pub javascript_enabled: Option<bool>, pub offline: Option<bool>, pub accept_downloads: Option<bool>, pub bypass_csp: Option<bool>, pub ignore_https_errors: Option<bool>, pub device_scale_factor: Option<f64>, pub extra_http_headers: Option<HashMap<String, String>>, pub base_url: Option<String>,
}
Options for creating a new browser context.

Allows customizing viewport, user agent, locale, timezone, geolocation, permissions, and other browser context settings.

See: https://playwright.dev/docs/api/class-browser#browser-new-context

Fields

viewport: Option<Viewport>

Sets consistent viewport for all pages in the context. Set to null via no_viewport(true) to disable viewport emulation.

no_viewport: Option<bool>

Disables viewport emulation when set to true.

user_agent: Option<String>

Custom user agent string

locale: Option<String>

Locale for the context (e.g., “en-GB”, “de-DE”, “fr-FR”)

timezone_id: Option<String>

Timezone identifier (e.g., “America/New_York”, “Europe/Berlin”)

geolocation: Option<Geolocation>

Geolocation coordinates

permissions: Option<Vec<String>>

List of permissions to grant (e.g., “geolocation”, “notifications”)

color_scheme: Option<String>

Emulates ‘prefers-colors-scheme’ media feature (“light”, “dark”, “no-preference”)

has_touch: Option<bool>

Whether the viewport supports touch events

is_mobile: Option<bool>

Whether the meta viewport tag is respected

javascript_enabled: Option<bool>

Whether JavaScript is enabled in the context

offline: Option<bool>

Emulates network being offline

accept_downloads: Option<bool>

Whether to automatically download attachments

bypass_csp: Option<bool>

Whether to bypass Content-Security-Policy

ignore_https_errors: Option<bool>

Whether to ignore HTTPS errors

device_scale_factor: Option<f64>

Device scale factor (default: 1)

extra_http_headers: Option<HashMap<String, String>>

Extra HTTP headers to send with every request

base_url: Option<String>

Base URL for relative navigation

Implementations

Source

impl BrowserContextOptions

pub fn builder() -> BrowserContextOptionsBuilder

Creates a new builder for BrowserContextOptions