#[non_exhaustive]pub struct ConnectOptions {
pub headers: Option<HashMap<String, String>>,
pub slow_mo: Option<f64>,
pub timeout: Option<f64>,
}Expand description
Options for BrowserType::connect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.headers: Option<HashMap<String, String>>Additional HTTP headers to send with the WebSocket handshake.
slow_mo: Option<f64>Slows down Playwright operations by the specified amount of milliseconds. Useful so that you can see what is going on.
timeout: Option<f64>Maximum time in milliseconds to wait for the connection to be established. Defaults to 30000 (30 seconds). Pass 0 to disable timeout.
Implementations