pub struct CDPSession { /* private fields */ }Expand description
A Chrome DevTools Protocol session for a page or browser context.
CDPSession is only available in Chromium-based browsers.
Implementations
Sourceimpl CDPSession
impl CDPSession
Sourcepub fn new(
parent: ParentOrConnection,
type_name: String,
guid: Arc<str>,
initializer: Value,
) -> Result<Self>
pub fn new( parent: ParentOrConnection, type_name: String, guid: Arc<str>, initializer: Value, ) -> Result<Self>
Creates a new CDPSession from protocol initialization.
Called by the object factory when the server sends a __create__ message.
Sourcepub async fn send(&self, method: &str, params: Option<Value>) -> Result<Value>
pub async fn send(&self, method: &str, params: Option<Value>) -> Result<Value>
Send a CDP command and return the result.
Arguments
method- The CDP method name (e.g.,"Runtime.evaluate")params- Optional JSON parameters for the method
Errors
Returns error if:
- The session has been detached
- The CDP method fails
- Communication with browser process fails
See: https://playwright.dev/docs/api/class-cdpsession#cdp-session-send
Sourcepub async fn detach(&self) -> Result<()>
pub async fn detach(&self) -> Result<()>
Detach the CDP session from the target.
After detaching, the session can no longer be used to send commands.
Errors
Returns error if:
- The session has already been detached
- Communication with browser process fails
See: https://playwright.dev/docs/api/class-cdpsession#cdp-session-detach