pub struct ConsoleMessageLocation {
pub url: String,
pub line_number: i32,
pub column_number: i32,
}Expand description
The source location of a console message.
Contains the URL, line number, and column number of the JavaScript code that produced the console message.
See: https://playwright.dev/docs/api/class-consolemessage#console-message-location
Fields
url: StringThe URL of the resource that produced the console message.
line_number: i32The line number in the resource (1-based).
column_number: i32The column number in the resource (0-based).