RequestSizes

Struct RequestSizes 

pub struct RequestSizes {
    pub request_body_size: i64,
    pub request_headers_size: i64,
    pub response_body_size: i64,
    pub response_headers_size: i64,
}
Resource size information for a request/response pair.

See: https://playwright.dev/docs/api/class-request#request-sizes

Fields

request_body_size: i64

Size of the request body in bytes. Set to 0 if there was no body.

request_headers_size: i64

Total number of bytes from the start of the HTTP request message until (and including) the double CRLF before the body.

response_body_size: i64

Size of the received response body in bytes.

response_headers_size: i64

Total number of bytes from the start of the HTTP response message until (and including) the double CRLF before the body.