TracingStartOptions

Struct TracingStartOptions 

pub struct TracingStartOptions {
    pub name: Option<String>,
    pub screenshots: Option<bool>,
    pub snapshots: Option<bool>,
    pub live: Option<bool>,
}
Options for starting a trace recording.

See: https://playwright.dev/docs/api/class-tracing#tracing-start

Fields

name: Option<String>

Custom name for the trace. Shown in trace viewer as the trace title.

screenshots: Option<bool>

Whether to capture screenshots during tracing. Screenshots are used as a timeline preview in the trace viewer.

snapshots: Option<bool>

Whether to capture DOM snapshots on each action.

live: Option<bool>

Whether to enable live trace updates while recording. When true, the trace viewer can attach and observe the trace as it is being captured, rather than waiting for the recording to finish. Useful for debugging long-running flows.

See: https://playwright.dev/docs/api/class-tracing#tracing-start-option-live