pub enum WaitForState {
Attached,
Detached,
Visible,
Hidden,
}Expand description
The state to wait for when using [Locator::wait_for()].
Matches Playwright’s WaitForSelectorState across all language bindings.
See: https://playwright.dev/docs/api/class-locator#locator-wait-for
Variants
Attached
Wait for the element to be present in the DOM (attached).
Detached
Wait for the element to be removed from the DOM.
Visible
Wait for the element to be visible (the default).
Hidden
Wait for the element to be hidden (invisible or not in the DOM).