#[non_exhaustive]pub struct WaitForOptions {
pub state: Option<WaitForState>,
pub timeout: Option<f64>,
}Expand description
Options for Locator::wait_for().
Configuration for waiting until an element satisfies a given state condition.
If no state is specified, defaults to Visible.
Use the builder pattern to construct options:
Example
use playwright_rs::{WaitForOptions, WaitForState};
// Wait until the element is visible
let options = WaitForOptions::builder()
.state(WaitForState::Visible)
.build();
// Wait until the element is hidden, with a custom timeout
let options = WaitForOptions::builder()
.state(WaitForState::Hidden)
.timeout(5000.0)
.build();See: https://playwright.dev/docs/api/class-locator#locator-wait-for
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: Option<WaitForState>The element state to wait for (defaults to Visible if not set)
timeout: Option<f64>Maximum time in milliseconds
Implementations
Sourceimpl WaitForOptions
impl WaitForOptions
Sourcepub fn builder() -> WaitForOptionsBuilder
pub fn builder() -> WaitForOptionsBuilder
Create a new builder for WaitForOptions